Libp2pNetwork

Struct Libp2pNetwork 

pub struct Libp2pNetwork {
    pub swarm: Swarm<ChatBehaviour>,
    pub local_peer_id: PeerId,
    pub dht_discovery_enabled: bool,
    pub bootstrap_peer_ids: Vec<PeerId>,
    /* private fields */
}
Shared libp2p network implementation fields used by both native and WASM builds.

Fields

swarm: Swarm<ChatBehaviour>local_peer_id: PeerIddht_discovery_enabled: boolbootstrap_peer_ids: Vec<PeerId>

Implementations

Source

impl Libp2pNetwork

pub fn on_new_listen_addr(&self, address: Multiaddr) -> Option<NetworkEvent>

pub fn on_external_addr_confirmed( &self, address: Multiaddr, ) -> Option<NetworkEvent>

pub fn on_connection_established( &mut self, peer_id: PeerId, endpoint: ConnectedPoint, num_established: u32, ) -> Option<NetworkEvent>

pub fn on_connection_closed( &mut self, peer_id: PeerId, endpoint: ConnectedPoint, num_established: u32, ) -> Option<NetworkEvent>

pub fn on_history_message( &mut self, peer: PeerId, message: Message<Vec<u8>, Vec<u8>>, ) -> Option<NetworkEvent>

pub fn on_identify_received(&mut self, peer_id: PeerId, info: Info)

pub fn on_gossipsub_message( &self, propagation_source: PeerId, message: Message, ) -> Option<NetworkEvent>

pub fn handle_swarm_event( &mut self, event: SwarmEvent<ChatBehaviourEvent>, ) -> Option<NetworkEvent>

Shared swarm event handler. Native and WASM modules call this for all common events, handling only platform-specific arms themselves.